@@ -207,6 +207,17 @@ class confDefault extends conf {
         $intUserCli->setDefault(0);
         $interface[]=$intUserCli;
 
+        $intUserRemote = new checkbox();
+        $intUserRemote->setName("interface.user.remote");
+        $intUserRemote->setLabel("Enable REMOTE_USER authentication");
+        $intUserRemote->setDesc("Authenticate using an external authenticator. " .
+            "This could be used for a single sign-on or other external authentication " .
+            "mechanism. This relies on the external authenticator to insert a \$_SERVER " .
+            "variable 'REMOTE_USER'. If this is not present, Zoph will fall back to it's " .
+            "own logon screen");
+        $intUserRemote->setDefault(false);
+        $interface[]=$intUserRemote;
+
         conf::addGroup($interface, "interface", "Interface settings",
             "Settings that define how Zoph looks");
 
