@@ -44,7 +44,7 @@ class language {
     private $translations=array();
 
     /**
-     * @var This defines what the base language is, the language the strings in the
+     * @var string This defines what the base language is, the language the strings in the
      * sourcecode are in.
      */
     public static $base="en";
@@ -59,13 +59,13 @@ class language {
      */
     function __construct($iso) {
         $this->name=$iso;
-        $this->filename=static::LANG_DIR. "/" . $iso;
+        $this->filename=settings::$php_loc . "/" . static::LANG_DIR. "/" . $iso;
         $this->iso=strtolower($iso);
     }
 
     /**
      * Open the file
-     * @return filedescriptor file
+     * @return int filedescriptor file
      */
     private function openFile() {
         if (file_exists($this->filename) && is_readable($this->filename)) {
@@ -117,7 +117,7 @@ class language {
                 log::msg("<b>" . $this->iso . "</b>:" . $line, log::MOREDEBUG, log::LANG);
             } else {
                 $strings=explode("=",$line);
-                $this->translations[$strings[0]]=$strings[1];
+                $this->translations[$strings[0]]=trim($strings[1]);
             }
         }
         fclose($file);
@@ -208,7 +208,8 @@ class language {
      * @return string null|iso
      */
     public static function exists($iso) {
-        $file=static::LANG_DIR . '/' . $iso;
+        $dir=settings::$php_loc . "/" . static::LANG_DIR;
+        $file=$dir . '/' . $iso;
         if (file_exists($file) && is_file($file)) {
             return $iso;
         } else {
@@ -280,6 +281,10 @@ class language {
         }
         return $return;
     }
+
+    public function getAllTranslations() {
+        return $this->translations;
+    }
 }
 
 /**
