@@ -110,15 +110,16 @@ class person extends zophTable implements Organizer {
      * This records in the database that this person appears on the photo
      * @param photo Photo to add the person to
      */
-    public function addPhoto(photo $photo) {
-        $pos = $photo->getLastPersonPos();
+    public function addPhoto(photo $photo, $row = 0) {
+        $pos = (new photo\people($photo))->getLastPos($row);
         $pos++;
 
         $qry=new insert(array("photo_people"));
         $qry->addParams(array(
             new param(":photo_id", (int) $photo->getId(), PDO::PARAM_INT),
             new param(":person_id", (int) $this->getId() , PDO::PARAM_INT),
-            new param(":position", (int) $pos, PDO::PARAM_INT)
+            new param(":position", (int) $pos, PDO::PARAM_INT),
+            new param(":row", (int) $row, PDO::PARAM_INT)
         ));
         $qry->execute();
     }
@@ -142,6 +143,7 @@ class person extends zophTable implements Organizer {
         $qry->addParams($params);
 
         $result=db::query($qry)->fetch(PDO::FETCH_ASSOC);
+        $row=$result["row"];
         $pos=$result["position"];
 
         $qry=new delete("photo_people");
@@ -153,12 +155,14 @@ class person extends zophTable implements Organizer {
 
         $where=new clause("photo_id=:photo_id");
         $where->addAnd(new clause("position>:pos"));
+        $where->addAnd(new clause("row=:row"));
 
         $qry->addSetFunction("position=position-1");
 
         $params=array(
             new param(":photo_id", (int) $photo->getId(), PDO::PARAM_INT),
-            new param(":pos", (int) $pos, PDO::PARAM_INT)
+            new param(":pos", (int) $pos, PDO::PARAM_INT),
+            new param(":row", (int) $row, PDO::PARAM_INT)
         );
 
         $qry->addParams($params);
