@@ -428,7 +428,7 @@ if ($displayCount <= 0) {
               </label>
               <fieldset class="checkboxlist multiple">
             <?php
-            $people = $photo->getPeople();
+            $people = (new photo/people($photo))->getAll();
             if ($people) {
                 $append = "";
                 foreach ($people as $person) {
