@@ -387,6 +387,17 @@ class keyMustBeNumericSecurityException extends securityException {}
  */
 class illegalValueSecurityException extends securityException {}
 
+/**
+ * Album Not Accessible Exception
+ * This exception is raised when a user tries to access a photo that
+ * he is not allowed to see. Since the Zoph UI hides all inaccessible
+ * photos, this should only happen if the user is, for example, changing
+ * parameters in the URL.
+ * @author Jeroen Roos
+ * @package zophException
+ */
+class albumNotAccessibleSecurityException extends securityException {}
+
 /**
  * Photo Not Accessible Exception
  * This exception is raised when a user tries to access a photo that
