@@ -50,7 +50,9 @@ $javascript=array();
 $scripts=array(
     "js/util.js",
     "js/xml.js",
-    "js/thumbview.js"
+    "js/thumbview.js",
+    "js/translate.js.php",
+    "js/error.js"
     );
 
 switch(basename($_SERVER["SCRIPT_NAME"])) {
@@ -62,6 +64,7 @@ case "config.php":
     $scripts[]="js/conf.js";
     break;
 case "photo.php":
+    $scripts[]="js/photoPeople.js";
 case "place.php":
     $scripts[]="js/json.js";
     $scripts[]="js/locationLookup.js";
@@ -81,7 +84,7 @@ if (conf::get("maps.provider")) {
     $scripts[]="js/maps.js";
     if (conf::get("maps.provider") == "googlev3") {
         $scripts[]="https://maps.googleapis.com/maps/api/js";
-        $scripts[]="js/leaflet/GoogleMutant.js";
+        $scripts[]="js/Leaflet.GoogleMutant.js";
     } else if (conf::get("maps.provider") == "mapbox") {
         $javascript[]="var mapbox_api_key = '" . conf::get("maps.mapbox.apikey") . "';";
     }
@@ -128,7 +131,6 @@ $tabs = array(
     translate("albums", 0) => "albums.php",
     translate("categories", 0) => "categories.php"
 );
-
 if ($user->canBrowsePeople()) {
     $tabs[translate("people", 0)] = "people.php";
 }
