@@ -1341,7 +1341,7 @@ div.slide-annotate dl.exif {
     clear: both;
 }
 
-div.slide-annotate dl.exif dt, 
+div.slide-annotate dl.exif dt,
 div.slide-annotate dl.exif dd {
     position: relative;
     float: none;
@@ -1391,16 +1391,16 @@ div.main:fullscreen div.slide-annotate dl.photodata dt {
 }
 
 div.main:fullscreen div.slide-annotate dl.photodata dt.icon {
-	width: 2em;
+    width: 2em;
 }
 
 dl.photodata {
-	width: 100%;
+    width: 100%;
 }
 
 dl.photodata dd {
-	min-height: 2.5em;
-	line-height: 2.5em;
+    min-height: 2.5em;
+    line-height: 2.5em;
 }
 
 dl.photodata dt {
@@ -1448,7 +1448,7 @@ dt.category {
 dt.people {
     background-image: url("<?= template::getImage("icons/people.png") ?>");
 }
- 
+
 ul#slide-categories,
 ul#slide-people,
 ul#slide-albums {
@@ -1516,6 +1516,10 @@ div#personlink  {
     margin: 0 0 15px 0;
 }
 
+ul.peoplerows {
+    list-style: none;
+}
+
 ul.peoplelinks {
     display: block;
     margin: 1px auto;
@@ -1540,6 +1544,111 @@ ul.peoplelinks li {
     opacity: 0.7;
 }
 
+div#editPeople {
+    clear: both;
+    overflow: hidden;
+    margin: 2em 0;
+    font-size: 90%;
+}
+
+ul.personrows {
+    display: block;
+    list-style: none;
+    text-align: center;
+    overflow: hidden;
+}
+
+div#editPeople ul.personrows > li {
+    border: 2px dashed rgba(0,0,0,0.3);
+    border-radius: 2px;
+    margin: 0.5em;
+    width: 90%;
+    min-height: 2em;
+}
+
+div#editPeople ul.people:empty::before {
+    position: relative;
+    content: "<?php echo translate('No people have been added to this photo.', false) ?>";
+    font-style: italic;
+    color: rgba(0,0,0,0.8);
+    top: 4px;
+}
+
+div#editPeople ul.people {
+    margin: auto;
+    overflow: hidden;
+    padding: 4px;
+}
+
+div#editPeople ul.people > li {
+    display: block;
+    float: left;
+    padding: 0.2em 0.8em;
+    margin: 0.3em;
+    height: 14px;
+    border-radius: 6px;
+    background: <?= colorScheme::getColor("tab_bg_color") ?>;
+    color: <?= colorScheme::getColor("tab_font_color") ?>;
+    border: 1px solid <?= colorScheme::getColor("table_border_color") ?>;
+    box-shadow: 3px 3px 2px rgba(0,0,0,0.2);
+}
+
+div#editPeople ul.people li:hover {
+    position: relative;
+    background: <?= colorScheme::getColor("selected_tab_bg_color") ?>;
+    color: <?= colorScheme::getColor("selected_tab_font_color") ?>;
+    left: 1px;
+    top: 1px;
+    box-shadow: 2px 2px 2px rgba(0,0,0,0.2);
+}
+
+div#editPeople ul.people li a {
+    text-decoration: none;
+    color: <?= colorScheme::getColor("tab_font_color") ?>;
+}
+
+div.left,
+div.right,
+div.up,
+div.down,
+div.remove,
+div.add {
+    width: 16px;
+    height: 16px;
+    margin: 0 5px 0 3px;
+    float: right;
+    background-size: cover;
+    background-repeat: no-repeat;
+    overflow: hidden;
+}
+
+div.left {
+    background-image: url("<?= template::getImage("icons/left.png") ?>");
+}
+
+div.right {
+    background-image: url("<?= template::getImage("icons/right.png") ?>");
+
+}
+
+div.up {
+    background-image: url("<?= template::getImage("icons/up.png") ?>");
+
+}
+
+div.down {
+    background-image: url("<?= template::getImage("icons/down.png") ?>");
+
+}
+
+div.remove {
+    background-image: url("<?= template::getImage("icons/remove.png") ?>");
+}
+
+div.add {
+    background-image: url("<?= template::getImage("icons/add.png") ?>");
+}
+
 div.inputhint {
     margin: -2px 0 15px 180px;
     clear: left;
@@ -2401,4 +2510,89 @@ div.message div.messageText h1 {
     margin-bottom: 2px;
 }
 
+
+div.modal {
+    position: fixed;
+    left: 50%;
+    top: 50%;
+    margin-top: -75px;
+    margin-left: -150px;
+    width: 300px;
+    min-height: 130px;
+    padding: 5px 10px;
+
+    border: 1px solid rgba(0,0,0,0.4);
+    background: #dddddd;
+    box-shadow: 10px 10px 30px rgba(0,0,0,0.6);
+    border-radius: 5px;
+}
+
+div.modal h1 {
+    font-size: 14px;
+    position: relative;
+    margin: 0 0 15px 0;
+    padding: 5px 10px;
+    left: -11px;
+    top: -6px;
+    border: 1px solid rgba(0,0,0,0.4);
+    border-bottom: 1px solid rgba(0,0,0,0.6);
+    border-radius: 5px 5px 0 0;
+}
+
+div.modal h1 img {
+    float: right;
+    margin: -1px;
+}
+
+div.modal input[type="button"] {
+    font-size: small;
+    width: auto;
+    height: auto;
+    padding: 7px 2em;
+    margin: 2em 1em;
+}
+
+ul#errors {
+    z-index: 400;
+    position: fixed;
+    left: 50%;
+    width: 300px;
+    margin: 0 auto auto -150px;
+    top: 0;
+    list-style: none;
+}
+
+ul#errors li {
+    z-index: 500;
+    color: #D8000C;
+    background-color: rgba(255, 186,186, 0.9);
+    display: block;
+    border-radius: 10px;
+    box-shadow: 20px 20px 20px rgba(0,0,0,0.5);
+    border: 1px solid rgba(0,0,0,0.9);
+    padding: 2em 1em;
+    margin: 1em;
+}
+
+ul#errors li:first-child {
+    border-top: none;
+    margin-top: 0;
+    padding-top: 0.5em;
+    border-radius: 0 0 10px 10px;
+}
+
+ul#errors li.deleted {
+    animation-iteration-count: 1;
+    animation: delete 2s forwards;
+}
+
+@keyframes delete {
+    0% {
+        opacity: 1;
+    }
+    100% {
+        opacity: 0;
+    }
+}
+
 /* vim: set syntax=css: */
