@@ -73,6 +73,8 @@ use template\template;
             <?= $tpl_share ?>
         </ul>
         <?= $tpl_image ?>
+        <div id="editPeople">
+        </div>
         <input class="updatebutton" type="submit" value="<?= translate("update", 0) ?>"><br>
         <?= template::createInput("title", $tpl_photo->get("title"), 64, translate("title"), 40,
             sprintf(translate("%s chars max"), "64")) ?>
@@ -111,22 +113,6 @@ use template\template;
         <?php endif ?>
         <label><?= translate("description") ?></label>
         <textarea name="description" cols="60" rows="4"><?= $tpl_photo->get("description") ?></textarea>
-        <br>
-        <label for="person_id[0]">
-            <?= translate("people") ?><br>
-        </label>
-        <span class="inputhint"><?php echo translate("(left to right, front to back).") ?></span>
-        <fieldset class="multiple">
-            <?php if ($tpl_people): ?>
-                <?php foreach ($tpl_people as $person): ?>
-                    <input class="remove" type="checkbox" name="_remove_person_id[]" value="<?= $person->getId()?>">
-                    <?= $person->getLink() ?><br>
-                <?php endforeach ?>
-            <?php else: ?>
-                <?= translate("No people have been added to this photo.") ?><br>
-            <?php endif ?>
-            <?= $tpl_personPulldown ?>
-        </fieldset>
         <label for="albums">
             <?= translate("albums") ?>
         </label>
